Stan Math Library: stan/math/rev/scal/fun/log2.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log2.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_LOG2_HPP
2 #define STAN_MATH_REV_SCAL_FUN_LOG2_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/log2.hpp>
6 #include <stan/math/prim/scal/fun/constants.hpp>
7
8 namespace stan {
9 namespace math {
10
11 namespace {
12 class log2_vari : public op_v_vari {
13 public:
14 explicit log2_vari(vari* avi) :
15 op_v_vari(stan::math::log2(avi->val_), avi) {
16 }
17 void chain() {
18 avi_->adj_ += adj_ / (stan::math::LOG_2 * avi_->val_);
19 }
20 };
21 }
22
53 inline var log2(const stan::math::var& a) {
54 return var(new log2_vari(a.vi_));
55 }
56
57 }
58 }
59 #endif
stan::math::LOG_2
const double LOG_2
The natural logarithm of 2, .
Definition: constants.hpp:33
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
constants.hpp
log2.hpp
stan::math::log2
fvar< T > log2(const fvar< T > &x)
Definition: log2.hpp:17

[ Stan Home Page ] © 2011–2016, Stan Development Team.